#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 DAV
version:              1.3.4
visibility:           public
id:                   DAV-1.3.4-7sSyJF9d3MIFhbgaDnWRQJ
key:                  DAV-1.3.4-7sSyJF9d3MIFhbgaDnWRQJ
license:              GPL-3.0-only
copyright:            Copyright (C) 2012-2020  Clint Adams
maintainer:           clint@debian.org
author:               Clint Adams
homepage:             http://floss.scru.org/hDAV
synopsis:             RFC 4918 WebDAV support
description:
    This is a library for the Web Distributed Authoring and Versioning
    (WebDAV) extensions to HTTP.  At present it supports a very small
    subset of client functionality.

    In addition, there is an executable, hdav, which can be used for
    command-line operation.

category:             Web
abi:                  f281369873f5c1a60b90641c5e487506
exposed:              True
exposed-modules:      Network.Protocol.HTTP.DAV
hidden-modules:       Network.Protocol.HTTP.DAV.TH
import-dirs:          /usr/lib/ghc-9.6.6/site-local/DAV-1.3.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/DAV-1.3.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/DAV-1.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dav
hs-libraries:         HSDAV-1.3.4-7sSyJF9d3MIFhbgaDnWRQJ
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-77TInwzUoLr4ZTB9XsbUbo containers-0.6.7
    data-default-0.7.1.3-5y5VYR5qIF5L6R23Ybd297 exceptions-0.10.7
    http-client-0.7.19-2UeAfN562pLBCSD1YRqnzt
    http-client-tls-0.3.6.4-56nnBZPBE3OE9myuO98KLr
    http-types-0.12.4-E7NglevSDUe4aFzTHGY2t7
    lens-5.3.4-A0YBIc9VyJWRWjUKb2vTX mtl-2.3.1 transformers-0.6.1.0
    transformers-base-0.4.6.1-LG0QBoPZdGK9NbdXEGTKgT
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv
    xml-conduit-1.9.1.4-EinTwPlhEXvICMqIr13G5A
    xml-hamlet-0.5.0.3-D3zIfQqoDpvLf9rL61lmjB

haddock-interfaces:   /usr/share/doc/haskell-dav/html/DAV.haddock
haddock-html:         /usr/share/doc/haskell-dav/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

